@@ -3,21 +3,23 @@ package Pcore::RPC::Server;
 use Pcore;
 use Pcore::HTTP::Server;
 use Pcore::WebSocket;
-use Pcore::Util::Scalar qw[is_plain_arrayref];
+use Pcore::RPC::Hub;
+use Pcore::Util::Scalar qw[is_plain_arrayref is_globref];
+use Pcore::Util::Data qw[to_cbor];
 use if $MSWIN, 'Win32API::File';
 
-sub run ( $class, $rpc_boot_args ) {
+sub run ( $type, $rpc_boot_args ) {
     $ENV->scan_deps if $rpc_boot_args->{scandeps};
 
     # ignore SIGINT
-    $SIG->{INT} = AE::signal INT => sub {
-        return;
-    };
+    $SIG->{INT} = AE::signal INT => sub { };
 
     my $cv = AE::cv;
 
     # create object
-    my $rpc = $class->new( $rpc_boot_args->{buildargs} // () );
+    my $rpc = $type->new( $rpc_boot_args->{buildargs} // () );
+
+    $rpc->{rpc} = Pcore::RPC::Hub->new( { id => $rpc_boot_args->{id} // P->uuid->v1mc_str, type => $type } );
 
     my $can_rpc_on_connect    = $rpc->can('RPC_ON_CONNECT');
     my $can_rpc_on_disconnect = $rpc->can('RPC_ON_DISCONNECT');
@@ -66,8 +68,8 @@ sub run ( $class, $rpc_boot_args ) {
     {
         no strict qw[refs];
 
-        if ( ${"$class\::RPC_LISTEN_EVENTS"} ) {
-            push $listen_events->@*, is_plain_arrayref ${"$class\::RPC_LISTEN_EVENTS"} ? ${"$class\::RPC_LISTEN_EVENTS"}->@* : ${"$class\::RPC_LISTEN_EVENTS"};
+        if ( ${"$type\::RPC_LISTEN_EVENTS"} ) {
+            push $listen_events->@*, is_plain_arrayref ${"$type\::RPC_LISTEN_EVENTS"} ? ${"$type\::RPC_LISTEN_EVENTS"}->@* : ${"$type\::RPC_LISTEN_EVENTS"};
         }
     }
 
@@ -96,7 +98,7 @@ sub run ( $class, $rpc_boot_args ) {
                         on_fire_event    => sub ( $ws, $key ) { return 1 },     # RPC client can fire server events
                         before_connect   => {
                             listen_events  => $listen_events,
-                            forward_events => ${"$class\::RPC_FORWARD_EVENTS"},
+                            forward_events => ${"$type\::RPC_FORWARD_EVENTS"},
                         },
                         ( $can_rpc_on_connect ? ( on_connect => sub ($ws) { $rpc->RPC_ON_CONNECT($ws); return } ) : () ),    #
                         ( $can_rpc_on_disconnect ? ( on_disconnect => sub ( $ws, $status ) { $rpc->RPC_ON_DISCONNECT( $ws, $status ); return; } ) : () ),
@@ -126,20 +128,36 @@ sub run ( $class, $rpc_boot_args ) {
         },
     } )->run;
 
+    my $data = to_cbor( {
+        pid    => $$,
+        id     => $rpc->{rpc}->{id},
+        type   => $type,
+        listen => $listen,
+        token  => $rpc_boot_args->{token}
+    } )->$*
+      . $LF;
+
     # open control handle
-    if ($MSWIN) {
-        Win32API::File::OsFHandleOpen( *FH, $rpc_boot_args->{ctrl_fh}, 'w' ) or die $!;
+    if ( is_globref $rpc_boot_args->{ctrl_fh} ) {
+        syswrite $rpc_boot_args->{ctrl_fh}, $data or die $!;
+
+        close $rpc_boot_args->{ctrl_fh} or die $!;
     }
     else {
-        open *FH, '>&=', $rpc_boot_args->{ctrl_fh} or die $!;
+        if ($MSWIN) {
+            Win32API::File::OsFHandleOpen( *FH, $rpc_boot_args->{ctrl_fh}, 'w' ) or die $!;
+        }
+        else {
+            open *FH, '>&=', $rpc_boot_args->{ctrl_fh} or die $!;
+        }
+
+        binmode *FH or die;
+
+        syswrite *FH, $data or die $!;
+
+        close *FH or die $!;
     }
 
-    binmode *FH or die;
-
-    print {*FH} "LISTEN:$listen\n";
-
-    close *FH or die;
-
     $cv->recv;
 
     exit;
@@ -152,11 +170,11 @@ sub run ( $class, $rpc_boot_args ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 9                    | Subroutines::ProhibitExcessComplexity - Subroutine "run" with high complexity score (27)                       |
+## |    3 | 11                   | Subroutines::ProhibitExcessComplexity - Subroutine "run" with high complexity score (32)                       |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 109                  | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 111                  | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 37                   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |    2 | 39                   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
